@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -230,9 +230,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_list_memberships():
+            async def sample_list_memberships():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.ListMembershipsRequest(
@@ -243,7 +243,7 @@ class GkeHubAsyncClient:
                 page_result = client.list_memberships(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -304,12 +304,20 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListMembershipsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -330,9 +338,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_list_features():
+            async def sample_list_features():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.ListFeaturesRequest(
@@ -342,7 +350,7 @@ class GkeHubAsyncClient:
                 page_result = client.list_features(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -403,12 +411,20 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListFeaturesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -429,9 +445,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_get_membership():
+            async def sample_get_membership():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.GetMembershipRequest(
@@ -439,7 +455,7 @@ class GkeHubAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_membership(request=request)
+                response = await client.get_membership(request=request)
 
                 # Handle the response
                 print(response)
@@ -499,7 +515,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -519,16 +540,16 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_get_feature():
+            async def sample_get_feature():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.GetFeatureRequest(
                 )
 
                 # Make the request
-                response = client.get_feature(request=request)
+                response = await client.get_feature(request=request)
 
                 # Handle the response
                 print(response)
@@ -588,7 +609,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -610,14 +636,13 @@ class GkeHubAsyncClient:
         Cloud**. To register other clusters, follow the instructions at
         https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
 
-            def sample_create_membership():
+            async def sample_create_membership():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.CreateMembershipRequest(
@@ -630,7 +655,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -720,7 +745,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -750,9 +780,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_create_feature():
+            async def sample_create_feature():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.CreateFeatureRequest(
@@ -763,7 +793,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -841,7 +871,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -870,14 +905,13 @@ class GkeHubAsyncClient:
         at
         https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
 
-            def sample_delete_membership():
+            async def sample_delete_membership():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.DeleteMembershipRequest(
@@ -889,7 +923,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -926,9 +960,6 @@ class GkeHubAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -962,7 +993,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -990,9 +1026,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_delete_feature():
+            async def sample_delete_feature():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.DeleteFeatureRequest(
@@ -1003,7 +1039,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1040,9 +1076,6 @@ class GkeHubAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1076,7 +1109,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1106,9 +1144,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_update_membership():
+            async def sample_update_membership():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.UpdateMembershipRequest(
@@ -1120,7 +1158,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1206,7 +1244,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1236,9 +1279,9 @@ class GkeHubAsyncClient:
 
             from google.cloud import gkehub_v1
 
-            def sample_update_feature():
+            async def sample_update_feature():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.UpdateFeatureRequest(
@@ -1249,7 +1292,7 @@ class GkeHubAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1335,7 +1378,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1361,14 +1409,13 @@ class GkeHubAsyncClient:
         **This method is used internally by Google-provided libraries.**
         Most clients should not need to call this method directly.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
 
-            def sample_generate_connect_manifest():
+            async def sample_generate_connect_manifest():
                 # Create a client
-                client = gkehub_v1.GkeHubClient()
+                client = gkehub_v1.GkeHubAsyncClient()
 
                 # Initialize request argument(s)
                 request = gkehub_v1.GenerateConnectManifestRequest(
@@ -1376,7 +1423,7 @@ class GkeHubAsyncClient:
                 )
 
                 # Make the request
-                response = client.generate_connect_manifest(request=request)
+                response = await client.generate_connect_manifest(request=request)
 
                 # Handle the response
                 print(response)
@@ -1417,7 +1464,12 @@ class GkeHubAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1431,7 +1483,9 @@ class GkeHubAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-gke-hub",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-gke-hub",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
