@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -60,7 +60,10 @@ class GkeHubClientMeta(type):
     _transport_registry["grpc"] = GkeHubGrpcTransport
     _transport_registry["grpc_asyncio"] = GkeHubGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[GkeHubTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[GkeHubTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -179,10 +182,16 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return self._transport
 
     @staticmethod
-    def feature_path(project: str, location: str, feature: str,) -> str:
+    def feature_path(
+        project: str,
+        location: str,
+        feature: str,
+    ) -> str:
         """Returns a fully-qualified feature string."""
         return "projects/{project}/locations/{location}/features/{feature}".format(
-            project=project, location=location, feature=feature,
+            project=project,
+            location=location,
+            feature=feature,
         )
 
     @staticmethod
@@ -195,10 +204,18 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def membership_path(project: str, location: str, membership: str,) -> str:
+    def membership_path(
+        project: str,
+        location: str,
+        membership: str,
+    ) -> str:
         """Returns a fully-qualified membership string."""
-        return "projects/{project}/locations/{location}/memberships/{membership}".format(
-            project=project, location=location, membership=membership,
+        return (
+            "projects/{project}/locations/{location}/memberships/{membership}".format(
+                project=project,
+                location=location,
+                membership=membership,
+            )
         )
 
     @staticmethod
@@ -211,7 +228,9 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -224,9 +243,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -235,9 +258,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -246,9 +273,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -257,10 +288,14 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -432,6 +467,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_memberships(
@@ -523,12 +559,20 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListMembershipsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -622,12 +666,20 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListFeaturesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -718,7 +770,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -807,7 +864,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -829,7 +891,6 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         Cloud**. To register other clusters, follow the instructions at
         https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
@@ -939,7 +1000,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1060,7 +1126,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1089,7 +1160,6 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         at
         https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
@@ -1145,9 +1215,6 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1181,7 +1248,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1259,9 +1331,6 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1295,7 +1364,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1425,7 +1499,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1554,7 +1633,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1580,7 +1664,6 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         **This method is used internally by Google-provided libraries.**
         Most clients should not need to call this method directly.
 
-
         .. code-block:: python
 
             from google.cloud import gkehub_v1
@@ -1639,7 +1722,12 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1660,7 +1748,9 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-gke-hub",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-gke-hub",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
