@@ -33,7 +33,9 @@ from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-gke-hub",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-gke-hub",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -56,6 +58,7 @@ class GkeHubTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -82,10 +85,6 @@ class GkeHubTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -107,6 +106,11 @@ class GkeHubTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -119,38 +123,63 @@ class GkeHubTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_memberships: gapic_v1.method.wrap_method(
-                self.list_memberships, default_timeout=None, client_info=client_info,
+                self.list_memberships,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_features: gapic_v1.method.wrap_method(
-                self.list_features, default_timeout=None, client_info=client_info,
+                self.list_features,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_membership: gapic_v1.method.wrap_method(
-                self.get_membership, default_timeout=None, client_info=client_info,
+                self.get_membership,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_feature: gapic_v1.method.wrap_method(
-                self.get_feature, default_timeout=None, client_info=client_info,
+                self.get_feature,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_membership: gapic_v1.method.wrap_method(
-                self.create_membership, default_timeout=None, client_info=client_info,
+                self.create_membership,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_feature: gapic_v1.method.wrap_method(
-                self.create_feature, default_timeout=None, client_info=client_info,
+                self.create_feature,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_membership: gapic_v1.method.wrap_method(
-                self.delete_membership, default_timeout=None, client_info=client_info,
+                self.delete_membership,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_feature: gapic_v1.method.wrap_method(
-                self.delete_feature, default_timeout=None, client_info=client_info,
+                self.delete_feature,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_membership: gapic_v1.method.wrap_method(
-                self.update_membership, default_timeout=None, client_info=client_info,
+                self.update_membership,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_feature: gapic_v1.method.wrap_method(
-                self.update_feature, default_timeout=None, client_info=client_info,
+                self.update_feature,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.generate_connect_manifest: gapic_v1.method.wrap_method(
                 self.generate_connect_manifest,
@@ -162,9 +191,9 @@ class GkeHubTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -276,5 +305,9 @@ class GkeHubTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("GkeHubTransport",)
