@@ -42,7 +42,7 @@ class Feature(proto.Message):
         name (str):
             Output only. The full, unique name of this Feature resource
             in the format ``projects/*/locations/*/features/*``.
-        labels (Sequence[google.cloud.gkehub_v1.types.Feature.LabelsEntry]):
+        labels (Mapping[str, str]):
             GCP labels for this Feature.
         resource_state (google.cloud.gkehub_v1.types.FeatureResourceState):
             Output only. State of the Feature resource
@@ -51,7 +51,7 @@ class Feature(proto.Message):
             Optional. Hub-wide Feature configuration. If
             this Feature does not support any Hub-wide
             configuration, this field may be unused.
-        membership_specs (Sequence[google.cloud.gkehub_v1.types.Feature.MembershipSpecsEntry]):
+        membership_specs (Mapping[str, google.cloud.gkehub_v1.types.MembershipFeatureSpec]):
             Optional. Membership-specific configuration
             for this Feature. If this Feature does not
             support any per-Membership configuration, this
@@ -75,7 +75,7 @@ class Feature(proto.Message):
             mutating a Feature.
         state (google.cloud.gkehub_v1.types.CommonFeatureState):
             Output only. The Hub-wide Feature state.
-        membership_states (Sequence[google.cloud.gkehub_v1.types.Feature.MembershipStatesEntry]):
+        membership_states (Mapping[str, google.cloud.gkehub_v1.types.MembershipFeatureState]):
             Output only. Membership-specific Feature
             status. If this Feature does report any
             per-Membership status, this field may be unused.
@@ -97,23 +97,56 @@ class Feature(proto.Message):
             deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
     resource_state = proto.Field(
-        proto.MESSAGE, number=3, message="FeatureResourceState",
+        proto.MESSAGE,
+        number=3,
+        message="FeatureResourceState",
+    )
+    spec = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="CommonFeatureSpec",
     )
-    spec = proto.Field(proto.MESSAGE, number=4, message="CommonFeatureSpec",)
     membership_specs = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=5, message="MembershipFeatureSpec",
+        proto.STRING,
+        proto.MESSAGE,
+        number=5,
+        message="MembershipFeatureSpec",
+    )
+    state = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="CommonFeatureState",
     )
-    state = proto.Field(proto.MESSAGE, number=6, message="CommonFeatureState",)
     membership_states = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=7, message="MembershipFeatureState",
+        proto.STRING,
+        proto.MESSAGE,
+        number=7,
+        message="MembershipFeatureState",
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=timestamp_pb2.Timestamp,
     )
-    create_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=9, message=timestamp_pb2.Timestamp,)
     delete_time = proto.Field(
-        proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=10,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -137,7 +170,11 @@ class FeatureResourceState(proto.Message):
         UPDATING = 4
         SERVICE_UPDATING = 5
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
 
 
 class FeatureState(proto.Message):
@@ -166,9 +203,20 @@ class FeatureState(proto.Message):
         WARNING = 2
         ERROR = 3
 
-    code = proto.Field(proto.ENUM, number=1, enum=Code,)
-    description = proto.Field(proto.STRING, number=2,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    code = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Code,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class CommonFeatureSpec(proto.Message):
@@ -201,7 +249,11 @@ class CommonFeatureState(proto.Message):
             Feature in this Hub.
     """
 
-    state = proto.Field(proto.MESSAGE, number=1, message="FeatureState",)
+    state = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="FeatureState",
+    )
 
 
 class MembershipFeatureSpec(proto.Message):
@@ -249,7 +301,11 @@ class MembershipFeatureState(proto.Message):
         oneof="feature_state",
         message=configmanagement_v1.MembershipState,
     )
-    state = proto.Field(proto.MESSAGE, number=1, message="FeatureState",)
+    state = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="FeatureState",
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
